@@ -24,8 +24,8 @@ static int init_vsl(int argc, char **argv)
 
 	if (m_vd != NULL)
 	{
-		VSL_Delete(m_vd);
-		VSM_Close(m_vd);
+		VSM_ReOpen(m_vd, 1);
+		return 0;
 	}
 
 	vd = VSM_New();
@@ -36,13 +36,14 @@ static int init_vsl(int argc, char **argv)
 		VSL_Arg(vd, c, optarg);
 	}
 
+	VSL_NonBlocking(vd, 1);
+
 	if (VSL_Open(vd, 1))
 	{
 		return -1;
 	}
 
 	m_vd = vd;
-
 	return 0;
 }
 
